@@ -1,5 +1,5 @@
 /*
- * Reads and displays CD-ROM volume name 
+ * Reads and displays CD-ROM volume name
  *
  * Several people have asked how to read CD volume names so I wrote this
  * small program to do it.
@@ -27,13 +27,18 @@
  ********************************************************************
  *
  */
+#include "i18n.h"
+
+#ifndef DEFAULTDEVICE
+#error DEFAULTDEVICE not set, check Makefile
+#endif
 
 #include <unistd.h>
 #include <stdio.h>
 #include <errno.h>
 #include <sys/types.h>
 #include <sys/stat.h>
-#include <fcntl.h>    
+#include <fcntl.h>
 
 int main(int argc, char *argv[])
 {
@@ -42,30 +47,32 @@ int main(int argc, char *argv[])
   char *device;
   char buffer[33];
 
+  I18NCODE
+
   if (argc == 2) {
     device = argv[1];
   } else if (argc == 1) {
-    device = "/dev/cdrom";
+    device = DEFAULTDEVICE;
   } else {
-    fprintf(stderr, "usage: volname [<device-file>]\n");
+    fprintf(stderr, _("usage: volname [<device-file>]\n"));
     exit(1);
   }
 
   fd = open(device, O_RDONLY);
   if (fd == -1) {
-    perror("volname");
+    perror(_("volname"));
     exit(1);
   }
 
   status = lseek(fd, 32808, SEEK_SET);
   if (status == -1) {
-    perror("volname");
+    perror(_("volname"));
     exit(1);
   }
 
   status = read(fd, buffer, 32);
   if (status == -1) {
-    perror("volname");
+    perror(_("volname"));
     exit(1);
   }
 
